@@ -21,6 +21,7 @@ extern "C" {
 
 /* Library modules */
 #include "re_aes.h"
+#include "re_async.h"
 #include "re_base64.h"
 #include "re_bfcp.h"
 #include "re_btrace.h"
@@ -34,7 +35,6 @@ extern "C" {
 #include "re_httpauth.h"
 #include "re_ice.h"
 #include "re_jbuf.h"
-#include "re_lock.h"
 #include "re_net.h"
 #include "re_main.h"
 #include "re_md5.h"
@@ -45,6 +45,7 @@ extern "C" {
 #include "re_json.h"
 #include "re_rtmp.h"
 #include "re_rtp.h"
+#include "re_rtpext.h"
 #include "re_sdp.h"
 #include "re_uri.h"
 #include "re_sip.h"
@@ -56,6 +57,7 @@ extern "C" {
 #include "re_sys.h"
 #include "re_tcp.h"
 #include "re_telev.h"
+#include "re_thread.h"
 #include "re_tmr.h"
 #include "re_trace.h"
 #include "re_tls.h"
